@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from paste.deploy.converters import asbool
 from paste.httpexceptions import HTTPFound, HTTPUnauthorized
 from paste.httpheaders import SET_COOKIE
 from paste.request import get_cookies, construct_url, parse_formvars, resolve_relative_url
@@ -256,3 +255,15 @@ def make_redirecting_plugin(login_form_path=None,
                                    password_field,
                                    force_https,
                                    **kw)
+
+def asbool(obj):
+    if isinstance(obj, (str, unicode)):
+        obj = obj.strip().lower()
+        if obj in ['true', 'yes', 'on', 'y', 't', '1']:
+            return True
+        elif obj in ['false', 'no', 'off', 'n', 'f', '0']:
+            return False
+        else:
+            raise ValueError(
+                "String is not true/false: %r" % obj)
+    return bool(obj)
