@@ -63,6 +63,8 @@ class TestCookieRedirectingFormPlugin(FixtureBase):
                                          rememberer_name='cookie',
                                          login_redirect_method='cookie',
                                          logout_redirect_method='cookie',
+                                         username_field='usern',
+                                         password_field='passw',
                                          force_https='y')
         self.assertEqual(plugin.login_form_path, '/form')
         self.assertEqual(plugin.login_handler_path, '/login')
@@ -70,6 +72,9 @@ class TestCookieRedirectingFormPlugin(FixtureBase):
         self.assertEqual(plugin.rememberer_name, 'cookie')
         self.assertEqual(plugin.login_redirect_method, 'cookie')
         self.assertEqual(plugin.logout_redirect_method, 'cookie')
+        self.assertEqual(plugin.logout_redirect_method, 'cookie')
+        self.assertEqual(plugin.username_field, 'usern')
+        self.assertEqual(plugin.password_field, 'passw')
         self.assertEqual(plugin.force_https, True)
 
     def test_implements(self):
@@ -133,6 +138,14 @@ class TestCookieRedirectingFormPlugin(FixtureBase):
         self.assertEqual(value, 'http://localhost/bla')
         self.assertEqual(app.code, 302)
 
+    def test_login_custom_fields_names(self):
+        environ = self.app.post('/login', params={'usern': 'christ',
+            'passw': 'jesus'}).req.environ
+        self.plugin = self._make_one(password_field='passw',
+                                     username_field='usern')
+        result = self.plugin.identify(environ)
+        self.assertEqual(result, {'login': 'christ', 'password': 'jesus'})
+
     def test_logout(self):
         environ = self.app.post('/logout').req.environ
         result = self.plugin.identify(environ)
